@@ -10,14 +10,27 @@ import logging, os
 __all__ = ['connect', 'start_host', 'ScriptHost', 'PluginHost']
 
 
+# Required for python 2.6
+class NullHandler(logging.Handler):
+    def emit(self, record):
+        pass
+
+
 def connect(address=None, port=None, vim_compatible=False):
     client = Client(RPCStream(MsgpackStream(UvStream(address, port))),
                     vim_compatible)
     client.discover_api()
     return client.vim
 
+
+def spawn(argv):
+    client = Client(RPCStream(MsgpackStream(UvStream(spawn_argv=argv))))
+    client.discover_api()
+    return client.vim
+
+
 def start_host(address=None, port=None):
-    logging.root.addHandler(logging.NullHandler())
+    logging.root.addHandler(NullHandler())
     logger = logging.getLogger(__name__)
     info = logger.info
     if 'NEOVIM_PYTHON_LOG_FILE' in os.environ:
@@ -35,11 +48,9 @@ def start_host(address=None, port=None):
             if isinstance(l, int):
                 level = l
         logger.setLevel(level)
-    pass # replaces next logging statement
-    #info('connecting to neovim')
+    info('connecting to neovim')
     vim = connect(address, port, vim_compatible=True)
-    pass # replaces next logging statement
-    #info('connected to neovim')
+    info('connected to neovim')
     with PluginHost(vim, discovered_plugins=[ScriptHost]) as host:
         host.run()
 
