@@ -49,13 +49,11 @@ class Client(object):
         parent = gr.parent
 
         def response_cb(err, result):
-            pass # replaces next logging statement
-            #debug('response is available for greenlet %s, switching back', gr)
+            debug('response is available for greenlet %s, switching back', gr)
             gr.switch(err, result)
 
         self.stream.send(method, args, response_cb)
-        pass # replaces next logging statement
-        #debug('yielding from greenlet %s to wait for response', gr)
+        debug('yielding from greenlet %s to wait for response', gr)
         return parent.switch()
 
 
@@ -67,15 +65,13 @@ class Client(object):
             response['result'] = result
             self.stream.loop_stop()
 
-        pass # replaces next logging statement
-        #debug('will now perform a blocking rpc request: %s, %s', method, args)
+        debug('will now perform a blocking rpc request: %s, %s', method, args)
         self.stream.send(method, args, response_cb)
         queue = []
         msg = self.next_message()
 
         while msg:
-            pass # replaces next logging statement
-            #debug('message received while waiting for rpc response: %s', msg)
+            debug('message received while waiting for rpc response: %s', msg)
             queue.append(msg)
             if response:
                 break
@@ -114,8 +110,7 @@ class Client(object):
                 # never leave this state
                 self.pending.appendleft(msg)
                 raise msg[1]
-            pass # replaces next logging statement
-            #debug('returning message: %s', msg)
+            debug('returning message: %s', msg)
             return msg
 
 
@@ -140,8 +135,7 @@ class Client(object):
             self.pending.append(('eof', err,))
             self.stream.loop_stop()
 
-        pass # replaces next logging statement
-        #debug('will block until a message is available')
+        debug('will block until a message is available')
         self.stream.loop_start(request_cb, notification_cb, error_cb)
 
         msg = self.next_pending_message()
@@ -157,28 +151,23 @@ class Client(object):
         def request_handler():
             try:
                 rv = self.request_cb(name, args)
-                pass # replaces next logging statement
-                #debug('greenlet %s completed, sending %s as response', gr, rv)
+                debug('greenlet %s completed, sending %s as response', gr, rv)
                 reply_fn(rv)
             except Exception as e:
                 self.error_cb(e)
                 if self.loop_running:
                     err_str = format_exc(5)
-                    pass # replaces next logging statement
-                    #warn("error caught while processing call '%s %s': %s",
-                         #name,
-                         #args,
-                         #err_str)
+                    warn("error caught while processing call '%s %s': %s",
+                         name,
+                         args,
+                         err_str)
                     reply_fn(err_str, error=True)
-                    pass # replaces next logging statement
-                    #debug('sent "%s" as response', err_str)
-            pass # replaces next logging statement
-            #debug('greenlet %s is now dying...', gr)
+                    debug('sent "%s" as response', err_str)
+            debug('greenlet %s is now dying...', gr)
             self.greenlets.remove(gr)
 
         gr = greenlet.greenlet(request_handler)
-        pass # replaces next logging statement
-        #debug('received rpc request, greenlet %s will handle it', gr)
+        debug('received rpc request, greenlet %s will handle it', gr)
         self.greenlets.add(gr)
         gr.switch()
 
@@ -187,31 +176,26 @@ class Client(object):
         def notification_handler():
             try:
                 self.notification_cb(name, args)
-                pass # replaces next logging statement
-                #debug('greenlet %s completed', gr)
+                debug('greenlet %s completed', gr)
             except Exception as e:
                 self.error_cb(e)
                 if self.loop_running:
                     err_str = format_exc(5)
-                    pass # replaces next logging statement
-                    #warn("error caught while processing event '%s %s': %s",
-                         #name,
-                         #args,
-                         #err_str)
-            pass # replaces next logging statement
-            #debug('greenlet %s is now dying...', gr)
+                    warn("error caught while processing event '%s %s': %s",
+                         name,
+                         args,
+                         err_str)
+            debug('greenlet %s is now dying...', gr)
             self.greenlets.remove(gr)
 
         gr = greenlet.greenlet(notification_handler)
-        pass # replaces next logging statement
-        #debug('received rpc notification, greenlet %s will handle it', gr)
+        debug('received rpc notification, greenlet %s will handle it', gr)
         self.greenlets.add(gr)
         gr.switch()
 
 
     def on_error(self, err):
-        pass # replaces next logging statement
-        #warn('caught error: %s', err)
+        warn('caught error: %s', err)
         self.error_cb(err)
 
 
@@ -220,16 +204,14 @@ class Client(object):
 
         try:
             assert not self.loop_running
-            pass # replaces next logging statement
-            #info('starting message loop')
+            info('starting message loop')
             self.request_cb = request_cb
             self.notification_cb = notification_cb
             self.error_cb = error_cb
             self.loop_running = True
 
             if profiling:
-                pass # replaces next logging statement
-                #info('starting profiler')
+                info('starting profiler')
                 pr = cProfile.Profile()
                 pr.enable()
 
@@ -248,8 +230,7 @@ class Client(object):
             if profiling:
                 pr.disable()
                 report = os.path.abspath('.nvim-python-client.profile')
-                pass # replaces next logging statement
-                #info('stopped profiler, writing report to %s', report)
+                info('stopped profiler, writing report to %s', report)
                 s = StringIO.StringIO()
                 ps = pstats.Stats(pr, stream=s)
                 ps.strip_dirs().sort_stats('tottime').print_stats(30)
@@ -257,8 +238,7 @@ class Client(object):
                 with open(report, 'w') as f:
                     f.write(s.getvalue())
 
-            pass # replaces next logging statement
-            #info('exiting message loop')
+            info('exiting message loop')
             self.loop_running = False
             self.request_cb = None
             self.notification_cb = None
