@@ -23,18 +23,16 @@ class MsgpackStream(object):
 
             while True:
                 try:
-                    pass # replaces next logging statement
-                    #debug('waiting for message...')
+                    debug('waiting for message...')
                     msg = self.unpacker.next()
-                    pass # replaces next logging statement
-                    #debug('received message: %s', msg)
+                    debug('received message: %s', msg)
                     msg_cb(msg)
                 except StopIteration:
-                    pass # replaces next logging statement
-                    #debug('unpacker needs more data...')
+                    debug('unpacker needs more data...')
                     break
 
         self.stream.loop_start(data_cb, error_cb)
+        debug('exiting msgpack stream loop')
 
 
     def loop_stop(self):
