@@ -36,28 +36,24 @@ class RPCStream(object):
                 #   - msg[1]: id
                 #   - msg[2]: method name
                 #   - msg[3]: arguments
-                pass # replaces next logging statement
-                #debug('received request: %s, %s', msg[2], msg[3])
+                debug('received request: %s, %s', msg[2], msg[3])
                 request_cb(msg[2], msg[3], reply_fn(self.stream, msg[1]))
             elif msg_type == 1:
                 # response to a previous request:
                 #   - msg[1]: the id
                 #   - msg[2]: error(if any)
                 #   - msg[3]: result(if not errored)
-                pass # replaces next logging statement
-                #debug('received response: %s, %s', msg[2], msg[3])
+                debug('received response: %s, %s', msg[2], msg[3])
                 self.pending_requests.pop(msg[1])(msg[2], msg[3])
             elif msg_type == 2:
                 # notification/event
                 #   - msg[1]: event name
                 #   - msg[2]: arguments
-                pass # replaces next logging statement
-                #debug('received notification: %s, %s', msg[1], msg[2])
+                debug('received notification: %s, %s', msg[1], msg[2])
                 notification_cb(msg[1], msg[2])
             else:
                 error = 'Received invalid message %s' % msg
-                pass # replaces next logging statement
-                #warn(error)
+                warn(error)
                 raise Exception(error)
 
         self.stream.loop_start(msg_cb, error_cb)
@@ -66,6 +62,8 @@ class RPCStream(object):
             notification_cb(*self.posted_notifications.popleft())
             self.stream.loop_start(msg_cb, error_cb)
 
+        debug('exiting rpc stream loop')
+
 
     def loop_stop(self):
         self.stream.loop_stop()
